@@ -39,7 +39,7 @@ pub enum P2pBatchError {
 
 /// Inject multiple agent info entries into the peer store
 pub async fn inject_agent_infos<'iter, I: IntoIterator<Item = &'iter AgentInfoSigned> + Send>(
-    env: DbWrite<DbKindP2pAgentStore>,
+    env: DbWrite<DbKindP2pAgents>,
     iter: I,
 ) -> StateMutationResult<()> {
     Ok(p2p_put_all(&env, iter.into_iter()).await?)
@@ -47,7 +47,7 @@ pub async fn inject_agent_infos<'iter, I: IntoIterator<Item = &'iter AgentInfoSi
 
 /// Inject multiple agent info entries into the peer store in batches.
 pub async fn p2p_put_all_batch(
-    env: DbWrite<DbKindP2pAgentStore>,
+    env: DbWrite<DbKindP2pAgents>,
     rx: tokio::sync::mpsc::Receiver<P2pBatch>,
 ) {
     let stream = tokio_stream::wrappers::ReceiverStream::new(rx);
@@ -103,14 +103,14 @@ pub async fn p2p_put_all_batch(
 
 /// Helper function to get all the peer data from this conductor
 pub async fn all_agent_infos(
-    env: DbRead<DbKindP2pAgentStore>,
+    env: DbRead<DbKindP2pAgents>,
 ) -> StateQueryResult<Vec<AgentInfoSigned>> {
     env.async_reader(|r| Ok(r.p2p_list_agents()?)).await
 }
 
 /// Helper function to get a single agent info
 pub async fn get_single_agent_info(
-    env: DbRead<DbKindP2pAgentStore>,
+    env: DbRead<DbKindP2pAgents>,
     _space: DnaHash,
     agent: AgentPubKey,
 ) -> StateQueryResult<Option<AgentInfoSigned>> {
@@ -121,7 +121,7 @@ pub async fn get_single_agent_info(
 
 /// Interconnect every provided pair of conductors via their peer store databases
 #[cfg(any(test, feature = "test_utils"))]
-pub async fn exchange_peer_info(envs: Vec<DbWrite<DbKindP2pAgentStore>>) {
+pub async fn exchange_peer_info(envs: Vec<DbWrite<DbKindP2pAgents>>) {
     for (i, a) in envs.iter().enumerate() {
         for (j, b) in envs.iter().enumerate() {
             if i == j {
@@ -143,7 +143,7 @@ pub async fn exchange_peer_info(envs: Vec<DbWrite<DbKindP2pAgentStore>>) {
     }
 }
 
-async fn run_query<F, R>(db: DbRead<DbKindP2pAgentStore>, f: F) -> ConductorResult<R>
+async fn run_query<F, R>(db: DbRead<DbKindP2pAgents>, f: F) -> ConductorResult<R>
 where
     R: Send + 'static,
     F: FnOnce(PConnGuard) -> ConductorResult<R> + Send + 'static,
@@ -159,7 +159,7 @@ where
 
 /// Get agent info for a single agent
 pub async fn get_agent_info_signed(
-    environ: DbRead<DbKindP2pAgentStore>,
+    environ: DbRead<DbKindP2pAgents>,
     _kitsune_space: Arc<kitsune_p2p::KitsuneSpace>,
     kitsune_agent: Arc<kitsune_p2p::KitsuneAgent>,
 ) -> ConductorResult<Option<AgentInfoSigned>> {
@@ -171,7 +171,7 @@ pub async fn get_agent_info_signed(
 
 /// Get all agent info for a single space
 pub async fn list_all_agent_info(
-    environ: DbRead<DbKindP2pAgentStore>,
+    environ: DbRead<DbKindP2pAgents>,
     _kitsune_space: Arc<kitsune_p2p::KitsuneSpace>,
 ) -> ConductorResult<Vec<AgentInfoSigned>> {
     run_query(environ, move |mut conn| Ok(conn.p2p_list_agents()?)).await
@@ -179,7 +179,7 @@ pub async fn list_all_agent_info(
 
 /// Get all agent info for a single space near a basis loc
 pub async fn list_all_agent_info_signed_near_basis(
-    environ: DbRead<DbKindP2pAgentStore>,
+    environ: DbRead<DbKindP2pAgents>,
     _kitsune_space: Arc<kitsune_p2p::KitsuneSpace>,
     basis_loc: u32,
     limit: u32,
@@ -193,7 +193,7 @@ pub async fn list_all_agent_info_signed_near_basis(
 /// Get the peer density an agent is currently seeing within
 /// a given [`DhtArc`]
 pub async fn query_peer_density(
-    env: DbRead<DbKindP2pAgentStore>,
+    env: DbRead<DbKindP2pAgents>,
     kitsune_space: Arc<kitsune_p2p::KitsuneSpace>,
     dht_arc: DhtArc,
 ) -> ConductorResult<PeerViewBeta> {
@@ -220,7 +220,7 @@ pub async fn query_peer_density(
 
 /// Put single agent info into store
 pub async fn put_agent_info_signed(
-    environ: DbWrite<DbKindP2pAgentStore>,
+    environ: DbWrite<DbKindP2pAgents>,
     agent_info_signed: kitsune_p2p::agent_store::AgentInfoSigned,
 ) -> ConductorResult<()> {
     Ok(p2p_put(&environ, &agent_info_signed).await?)
@@ -239,7 +239,7 @@ fn is_expired(now: u64, info: &AgentInfoSigned) -> bool {
 
 /// Dump the agents currently in the peer store
 pub async fn dump_state(
-    env: DbRead<DbKindP2pAgentStore>,
+    env: DbRead<DbKindP2pAgents>,
     cell_id: Option<CellId>,
 ) -> StateQueryResult<P2pAgentsDump> {
     use std::fmt::Write;
@@ -304,22 +304,22 @@ pub async fn dump_state(
 mod tests {
     use super::*;
     use ::fixt::prelude::*;
-    use holochain_state::test_utils::test_p2p_agent_store_env;
+    use holochain_state::test_utils::test_p2p_agents_db;
     use kitsune_p2p::fixt::AgentInfoSignedFixturator;
 
     #[tokio::test(flavor = "multi_thread")]
     async fn test_store_agent_info_signed() {
         observability::test_run().ok();
 
-        let test_env = test_p2p_agent_store_env();
-        let env = test_env.env();
+        let test_db = test_p2p_agents_db();
+        let db = test_db.to_db();
 
         let agent_info_signed = fixt!(AgentInfoSigned, Predictable);
 
-        p2p_put(&env, &agent_info_signed).await.unwrap();
+        p2p_put(&db, &agent_info_signed).await.unwrap();
 
-        let ret = env
-            .from_permit(env.conn_permit().await)
+        let ret = db
+            .from_permit(db.conn_permit().await)
             .unwrap()
             .p2p_get_agent(&agent_info_signed.agent)
             .unwrap();
@@ -328,14 +328,14 @@ mod tests {
     }
 
     #[tokio::test(flavor = "multi_thread")]
-    async fn add_agent_info_to_peer_env() {
+    async fn add_agent_info_to_db() {
         observability::test_run().ok();
-        let t_env = test_p2p_agent_store_env();
-        let env = t_env.env();
+        let t_db = test_p2p_agents_db();
+        let db = t_db.to_db();
 
         // - Check no data in the store to start
-        let count = env
-            .from_permit(env.conn_permit().await)
+        let count = db
+            .from_permit(db.conn_permit().await)
             .unwrap()
             .p2p_list_agents()
             .unwrap()
@@ -352,12 +352,12 @@ mod tests {
         expect.sort_by(|a, b| a.agent.partial_cmp(&b.agent).unwrap());
 
         // - Inject some data
-        inject_agent_infos(env.clone(), agent_infos.iter())
+        inject_agent_infos(db.clone(), agent_infos.iter())
             .await
             .unwrap();
 
         // - Check the same data is now in the store
-        let mut agents = all_agent_infos(env.clone().into()).await.unwrap();
+        let mut agents = all_agent_infos(db.clone().into()).await.unwrap();
 
         agents.sort_by(|a, b| a.agent.partial_cmp(&b.agent).unwrap());
 
