@@ -5,11 +5,14 @@
 use std::{collections::HashMap, sync::Arc};
 
 use holo_hash::{DhtOpHash, DnaHash};
-use holochain_conductor_api::conductor::EnvironmentRootPath;
+use holochain_conductor_api::conductor::DatabaseRootPath;
 use holochain_p2p::dht_arc::{ArcInterval, DhtArcSet};
 use holochain_sqlite::{
     conn::{DbSyncLevel, DbSyncStrategy},
-    db::{DbKindAuthored, DbKindCache, DbKindDht, DbWrite, ReadAccess},
+    db::{
+        DbKindAuthored, DbKindCache, DbKindConductor, DbKindDht, DbKindP2pAgents, DbKindP2pMetrics,
+        DbKindWasm, DbWrite, ReadAccess,
+    },
     prelude::DatabaseResult,
 };
 use holochain_state::prelude::{from_blob, StateQueryResult};
@@ -32,7 +35,11 @@ use crate::core::{
     },
 };
 
-use super::{conductor::RwShare, error::ConductorResult};
+use super::{
+    conductor::RwShare,
+    error::ConductorResult,
+    p2p_agent_store::{self, P2pBatch},
+};
 use std::convert::TryInto;
 
 #[derive(Clone)]
@@ -41,10 +48,12 @@ use std::convert::TryInto;
 /// installed on this conductor.
 pub struct Spaces {
     map: RwShare<HashMap<DnaHash, Space>>,
-    root_env_dir: Arc<EnvironmentRootPath>,
-    db_sync_level: DbSyncStrategy,
+    pub(crate) db_dir: Arc<DatabaseRootPath>,
+    pub(crate) db_sync_strategy: DbSyncStrategy,
     /// The map of running queue consumer workflows.
-    queue_consumer_map: QueueConsumerMap,
+    pub(crate) queue_consumer_map: QueueConsumerMap,
+    pub(crate) conductor_db: DbWrite<DbKindConductor>,
+    pub(crate) wasm_db: DbWrite<DbKindWasm>,
 }
 
 #[derive(Clone)]
@@ -58,15 +67,24 @@ pub struct Space {
 
     /// The caches databases. These are shared across cells.
     /// There is one per unique Dna.
-    pub cache: DbWrite<DbKindCache>,
+    pub cache_db: DbWrite<DbKindCache>,
 
     /// The authored databases. These are shared across cells.
     /// There is one per unique Dna.
-    pub authored_env: DbWrite<DbKindAuthored>,
+    pub authored_db: DbWrite<DbKindAuthored>,
 
     /// The dht databases. These are shared across cells.
     /// There is one per unique Dna.
-    pub dht_env: DbWrite<DbKindDht>,
+    pub dht_db: DbWrite<DbKindDht>,
+
+    /// The database for storing AgentInfoSigned
+    pub p2p_agents_db: DbWrite<DbKindP2pAgents>,
+
+    /// The database for storing p2p MetricDatum(s)
+    pub p2p_metrics_db: DbWrite<DbKindP2pMetrics>,
+
+    /// The batch sender for writes to the p2p database.
+    pub p2p_batch_sender: tokio::sync::mpsc::Sender<P2pBatch>,
 
     /// A cache for slow database queries.
     pub dht_query_cache: DhtDbQueryCache,
@@ -96,16 +114,31 @@ pub struct TestSpace {
 impl Spaces {
     /// Create a new empty set of [`DnaHash`] spaces.
     pub fn new(
-        root_env_dir: EnvironmentRootPath,
-        db_sync_level: DbSyncStrategy,
-        queue_consumer_map: QueueConsumerMap,
-    ) -> Self {
-        Spaces {
+        root_db_dir: DatabaseRootPath,
+        db_sync_strategy: DbSyncStrategy,
+    ) -> ConductorResult<Self> {
+        let db_sync_level = match db_sync_strategy {
+            DbSyncStrategy::Fast => DbSyncLevel::Off,
+            DbSyncStrategy::Resilient => DbSyncLevel::Normal,
+        };
+        let conductor_db =
+            DbWrite::open_with_sync_level(root_db_dir.as_ref(), DbKindConductor, db_sync_level)?;
+        let wasm_db =
+            DbWrite::open_with_sync_level(root_db_dir.as_ref(), DbKindWasm, db_sync_level)?;
+        Ok(Spaces {
             map: RwShare::new(HashMap::new()),
-            root_env_dir: Arc::new(root_env_dir),
-            db_sync_level,
-            queue_consumer_map,
-        }
+            db_dir: Arc::new(root_db_dir),
+            db_sync_strategy,
+            queue_consumer_map: QueueConsumerMap::new(),
+            conductor_db,
+            wasm_db,
+        })
+    }
+
+    /// Get something from every space
+    pub fn get_from_spaces<R, F: FnMut(&Space) -> R>(&self, f: F) -> Vec<R> {
+        self.map
+            .share_ref(|spaces| spaces.values().map(f).collect())
     }
 
     /// Get the space if it exists or create it if it doesn't.
@@ -113,14 +146,11 @@ impl Spaces {
         self.get_or_create_space_ref(dna_hash, Space::clone)
     }
 
-    fn get_or_create_space_ref<F, R>(&self, dna_hash: &DnaHash, mut f: F) -> ConductorResult<R>
+    fn get_or_create_space_ref<F, R>(&self, dna_hash: &DnaHash, f: F) -> ConductorResult<R>
     where
-        F: FnMut(&Space) -> R,
+        F: Fn(&Space) -> R,
     {
-        match self
-            .map
-            .share_ref(|spaces| spaces.get(dna_hash).map(&mut f))
-        {
+        match self.map.share_ref(|spaces| spaces.get(dna_hash).map(&f)) {
             Some(r) => Ok(r),
             None => self
                 .map
@@ -129,8 +159,8 @@ impl Spaces {
                     std::collections::hash_map::Entry::Vacant(entry) => {
                         let space = Space::new(
                             Arc::new(dna_hash.clone()),
-                            &self.root_env_dir,
-                            self.db_sync_level,
+                            &self.db_dir,
+                            self.db_sync_strategy,
                         )?;
 
                         let r = f(&space);
@@ -143,17 +173,35 @@ impl Spaces {
 
     /// Get the cache database (this will create the space if it doesn't already exist).
     pub fn cache(&self, dna_hash: &DnaHash) -> ConductorResult<DbWrite<DbKindCache>> {
-        self.get_or_create_space_ref(dna_hash, |space| space.cache.clone())
+        self.get_or_create_space_ref(dna_hash, |space| space.cache_db.clone())
     }
 
     /// Get the authored database (this will create the space if it doesn't already exist).
-    pub fn authored_env(&self, dna_hash: &DnaHash) -> ConductorResult<DbWrite<DbKindAuthored>> {
-        self.get_or_create_space_ref(dna_hash, |space| space.authored_env.clone())
+    pub fn authored_db(&self, dna_hash: &DnaHash) -> ConductorResult<DbWrite<DbKindAuthored>> {
+        self.get_or_create_space_ref(dna_hash, |space| space.authored_db.clone())
     }
 
     /// Get the dht database (this will create the space if it doesn't already exist).
-    pub fn dht_env(&self, dna_hash: &DnaHash) -> ConductorResult<DbWrite<DbKindDht>> {
-        self.get_or_create_space_ref(dna_hash, |space| space.dht_env.clone())
+    pub fn dht_db(&self, dna_hash: &DnaHash) -> ConductorResult<DbWrite<DbKindDht>> {
+        self.get_or_create_space_ref(dna_hash, |space| space.dht_db.clone())
+    }
+
+    /// Get the peer database (this will create the space if it doesn't already exist).
+    pub fn p2p_agents_db(&self, dna_hash: &DnaHash) -> ConductorResult<DbWrite<DbKindP2pAgents>> {
+        self.get_or_create_space_ref(dna_hash, |space| space.p2p_agents_db.clone())
+    }
+
+    /// Get the peer database (this will create the space if it doesn't already exist).
+    pub fn p2p_metrics_db(&self, dna_hash: &DnaHash) -> ConductorResult<DbWrite<DbKindP2pMetrics>> {
+        self.get_or_create_space_ref(dna_hash, |space| space.p2p_metrics_db.clone())
+    }
+
+    /// Get the batch sender (this will create the space if it doesn't already exist).
+    pub fn p2p_batch_sender(
+        &self,
+        dna_hash: &DnaHash,
+    ) -> ConductorResult<tokio::sync::mpsc::Sender<P2pBatch>> {
+        self.get_or_create_space_ref(dna_hash, |space| space.p2p_batch_sender.clone())
     }
 
     #[instrument(skip(self))]
@@ -172,7 +220,7 @@ impl Spaces {
         let end = window.end;
         let max_ops: u32 = max_ops.try_into().unwrap_or(u32::MAX);
 
-        let env = self.dht_env(dna_hash)?;
+        let db = self.dht_db(dna_hash)?;
         let include_limbo = include_limbo
             .then(|| "\n")
             .unwrap_or("AND DhtOp.when_integrated IS NOT NULL\n");
@@ -214,7 +262,7 @@ impl Spaces {
                 holochain_sqlite::sql::sql_cell::FETCH_OP_HASHES_P2,
             )
         };
-        let results = env
+        let results = db
             .async_reader(move |txn| {
                 let hashes = txn
                     .prepare_cached(&sql)?
@@ -259,8 +307,8 @@ impl Spaces {
     ) -> ConductorResult<Vec<(holo_hash::DhtOpHash, holochain_types::dht_op::DhtOp)>> {
         const OPS_IN_MEMORY_BOUND_BYTES: usize = 3_000_000; // 3MB
                                                             // FIXME: Test this query.
-        let env = self.dht_env(dna_hash)?;
-        let results = env
+        let db = self.dht_db(dna_hash)?;
+        let results = db
             .async_reader(move |txn| {
                 let mut out = Vec::with_capacity(op_hashes.len());
                 let mut total_bytes = 0;
@@ -378,39 +426,60 @@ impl Spaces {
 impl Space {
     fn new(
         dna_hash: Arc<DnaHash>,
-        root_env_dir: &EnvironmentRootPath,
+        root_db_dir: &DatabaseRootPath,
         db_sync_strategy: DbSyncStrategy,
     ) -> ConductorResult<Self> {
+        use holochain_p2p::DnaHashExt;
+        let space = dna_hash.to_kitsune();
+        let db_sync_level = match db_sync_strategy {
+            DbSyncStrategy::Fast => DbSyncLevel::Off,
+            DbSyncStrategy::Resilient => DbSyncLevel::Normal,
+        };
         let cache = DbWrite::open_with_sync_level(
-            root_env_dir.as_ref(),
+            root_db_dir.as_ref(),
             DbKindCache(dna_hash.clone()),
-            match db_sync_strategy {
-                DbSyncStrategy::Fast => DbSyncLevel::Off,
-                DbSyncStrategy::Resilient => DbSyncLevel::Normal,
-            },
+            db_sync_level,
         )?;
-        let authored_env = DbWrite::open_with_sync_level(
-            root_env_dir.as_ref(),
+        let authored_db = DbWrite::open_with_sync_level(
+            root_db_dir.as_ref(),
             DbKindAuthored(dna_hash.clone()),
             DbSyncLevel::Normal,
         )?;
-        let dht_env = DbWrite::open_with_sync_level(
-            root_env_dir.as_ref(),
+        let dht_db = DbWrite::open_with_sync_level(
+            root_db_dir.as_ref(),
             DbKindDht(dna_hash.clone()),
-            match db_sync_strategy {
-                DbSyncStrategy::Fast => DbSyncLevel::Off,
-                DbSyncStrategy::Resilient => DbSyncLevel::Normal,
-            },
+            db_sync_level,
         )?;
+        let p2p_agents_db = DbWrite::open_with_sync_level(
+            root_db_dir.as_ref(),
+            DbKindP2pAgents(space.clone()),
+            db_sync_level,
+        )?;
+        let p2p_metrics_db = DbWrite::open_with_sync_level(
+            root_db_dir.as_ref(),
+            DbKindP2pMetrics(space),
+            db_sync_level,
+        )?;
+
+        let (tx, rx) = tokio::sync::mpsc::channel(100);
+        tokio::spawn(p2p_agent_store::p2p_put_all_batch(
+            p2p_agents_db.clone(),
+            rx,
+        ));
+        let p2p_batch_sender = tx;
+
         let countersigning_workspace = CountersigningWorkspace::new();
         let incoming_op_hashes = IncomingOpHashes::default();
         let incoming_ops_batch = IncomingOpsBatch::default();
-        let dht_query_cache = DhtDbQueryCache::new(dht_env.clone().into());
+        let dht_query_cache = DhtDbQueryCache::new(dht_db.clone().into());
         let r = Self {
             dna_hash,
-            cache,
-            authored_env,
-            dht_env,
+            cache_db: cache,
+            authored_db,
+            dht_db,
+            p2p_agents_db,
+            p2p_metrics_db,
+            p2p_batch_sender,
             countersigning_workspace,
             incoming_op_hashes,
             incoming_ops_batch,
@@ -439,11 +508,7 @@ impl TestSpaces {
             .prefix("holochain-test-environments")
             .tempdir()
             .unwrap();
-        let spaces = Spaces::new(
-            temp_dir.path().to_path_buf().into(),
-            Default::default(),
-            queue_consumer_map.clone(),
-        );
+        let spaces = Spaces::new(temp_dir.path().to_path_buf().into(), Default::default()).unwrap();
         spaces.map.share_mut(|map| {
             map.extend(
                 test_spaces
