@@ -31,15 +31,15 @@ pub const DEFAULT_RECEIPT_BUNDLE_SIZE: u8 = 5;
 /// flooding the network with spurious publishes.
 pub const MIN_PUBLISH_INTERVAL: time::Duration = time::Duration::from_secs(60 * 5);
 
-#[instrument(skip(env, network, trigger_self))]
+#[instrument(skip(db, network, trigger_self))]
 pub async fn publish_dht_ops_workflow(
-    env: DbWrite<DbKindAuthored>,
+    db: DbWrite<DbKindAuthored>,
     network: &(dyn HolochainP2pDnaT + Send + Sync),
     trigger_self: &TriggerSender,
     agent: AgentPubKey,
 ) -> WorkflowResult<WorkComplete> {
     let mut complete = WorkComplete::Complete;
-    let to_publish = publish_dht_ops_workflow_inner(env.clone().into(), agent).await?;
+    let to_publish = publish_dht_ops_workflow_inner(db.clone().into(), agent).await?;
 
     // Commit to the network
     tracing::info!("sending to {} basis locations", to_publish.len());
@@ -59,7 +59,7 @@ pub async fn publish_dht_ops_workflow(
 
     tracing::info!("sent {} ops", success.len());
     let now = std::time::SystemTime::now().duration_since(std::time::UNIX_EPOCH)?;
-    let continue_publish = env
+    let continue_publish = db
         .async_commit(move |writer| {
             for hash in success {
                 mutations::set_last_publish_time(writer, &hash, now)?;
@@ -83,13 +83,13 @@ pub async fn publish_dht_ops_workflow(
 
 /// Read the authored for ops with receipt count < R
 pub async fn publish_dht_ops_workflow_inner(
-    env: DbRead<DbKindAuthored>,
+    db: DbRead<DbKindAuthored>,
     agent: AgentPubKey,
 ) -> WorkflowResult<HashMap<AnyDhtHash, Vec<(DhtOpHash, DhtOp)>>> {
     // Ops to publish by basis
     let mut to_publish = HashMap::new();
 
-    for op_hashed in publish_query::get_ops_to_publish(agent, &env).await? {
+    for op_hashed in publish_query::get_ops_to_publish(agent, &db).await? {
         let (op, op_hash) = op_hashed.into_inner();
         // For every op publish a request
         // Collect and sort ops by basis
@@ -131,7 +131,7 @@ mod tests {
 
     /// publish ops setup
     async fn setup(
-        env: DbWrite<DbKindAuthored>,
+        db: DbWrite<DbKindAuthored>,
         num_agents: u32,
         num_hash: u32,
         panic_on_publish: bool,
@@ -147,7 +147,7 @@ mod tests {
         let mut link_add_fixt = CreateLinkFixturator::new(Unpredictable);
         let author = fake_agent_pubkey_1();
 
-        env.conn()
+        db.conn()
             .unwrap()
             .with_commit_sync(|txn| {
                 for _ in 0..num_hash {
@@ -225,12 +225,12 @@ mod tests {
 
     /// Call the workflow
     async fn call_workflow(
-        env: DbWrite<DbKindAuthored>,
+        db: DbWrite<DbKindAuthored>,
         dna_network: HolochainP2pDna,
         author: AgentPubKey,
     ) {
         let (trigger_sender, _) = TriggerSender::new();
-        publish_dht_ops_workflow(env.clone().into(), &dna_network, &trigger_sender, author)
+        publish_dht_ops_workflow(db.clone().into(), &dna_network, &trigger_sender, author)
             .await
             .unwrap();
     }
@@ -249,15 +249,15 @@ mod tests {
         tokio_helper::block_forever_on(async {
             observability::test_run().ok();
 
-            // Create test env
-            let test_env = test_authored_env();
-            let env = test_env.env();
+            // Create test db
+            let test_db = test_authored_db();
+            let db = test_db.to_db();
 
             // Setup
             let (_network, dna_network, author, recv_task, rx_complete) =
-                setup(env.clone(), num_agents, num_hash, false).await;
+                setup(db.clone(), num_agents, num_hash, false).await;
 
-            call_workflow(env.clone().into(), dna_network, author).await;
+            call_workflow(db.clone().into(), dna_network, author).await;
 
             // Wait for expected # of responses, or timeout
             tokio::select! {
@@ -269,7 +269,7 @@ mod tests {
 
             let check = async move {
                 recv_task.await.unwrap();
-                fresh_reader_test!(env, |txn: Transaction| {
+                fresh_reader_test!(db, |txn: Transaction| {
                     let unpublished_ops: bool = txn
                         .query_row(
                             "SELECT EXISTS(SELECT 1 FROM DhtOp WHERE last_publish_time IS NULL)",
@@ -303,16 +303,16 @@ mod tests {
         tokio_helper::block_forever_on(async {
             observability::test_run().ok();
 
-            // Create test env
-            let test_env = test_authored_env();
-            let env = test_env.env();
+            // Create test db
+            let test_db = test_authored_db();
+            let db = test_db.to_db();
 
             // Setup
             let (_network, dna_network, author, _, _) =
-                setup(env.clone(), num_agents, num_hash, true).await;
+                setup(db.clone(), num_agents, num_hash, true).await;
 
             // Update the authored to have complete receipts
-            env.conn()
+            db.conn()
                 .unwrap()
                 .with_commit_test(|txn| {
                     txn.execute("UPDATE DhtOp SET receipts_complete = 1", [])
@@ -321,7 +321,7 @@ mod tests {
                 .unwrap();
 
             // Call the workflow
-            call_workflow(env.clone().into(), dna_network, author).await;
+            call_workflow(db.clone().into(), dna_network, author).await;
 
             // If we can wait a while without receiving any publish, we have succeeded
             tokio::time::sleep(Duration::from_millis(
@@ -355,11 +355,11 @@ mod tests {
             async {
                 observability::test_run().ok();
 
-                // Create test env
-                let test_env = test_authored_env();
+                // Create test db
+                let test_db = test_authored_db();
                 let keystore = holochain_state::test_utils::test_keystore();
-                let dht_env = test_dht_env();
-                let env = test_env.env();
+                let dht_db = test_dht_db();
+                let db = test_db.to_db();
                 let zome = fixt!(Zome);
 
                 let dna = fixt!(DnaHash);
@@ -392,10 +392,10 @@ mod tests {
                 let eu_entry_type = entry_type_fixt.next().unwrap();
 
                 // Genesis and produce ops to clear these from the chains
-                fake_genesis(env.clone(), dht_env.env(), keystore.clone())
+                fake_genesis(db.clone(), dht_db.to_db(), keystore.clone())
                     .await
                     .unwrap();
-                env.conn()
+                db.conn()
                     .unwrap()
                     .execute("UPDATE DhtOp SET receipts_complete = 1", [])
                     .unwrap();
@@ -403,8 +403,8 @@ mod tests {
 
                 // Put data in elements
                 let source_chain = SourceChain::new(
-                    env.clone().into(),
-                    dht_env.env(),
+                    db.clone().into(),
+                    dht_db.to_db(),
                     keystore.clone(),
                     author.clone(),
                 )
@@ -441,7 +441,7 @@ mod tests {
                     .unwrap();
 
                 source_chain.flush(&dna_network).await.unwrap();
-                let (entry_create_header, entry_update_header) = env
+                let (entry_create_header, entry_update_header) = db
                     .conn()
                     .unwrap()
                     .with_commit_test(|writer| {
@@ -591,7 +591,7 @@ mod tests {
                     }
                 }
 
-                call_workflow(env.clone().into(), dna_network, author).await;
+                call_workflow(db.clone().into(), dna_network, author).await;
 
                 // Wait for expected # of responses, or timeout
                 tokio::select! {
